==> openjdk-src-22.0.1.u0-1-aarch64.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/LocaleNames_ii.java <==
/*
 * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class LocaleNames_ii extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "BR", "\ua020\ua46d" },
            { "CN", "\ua34f\ua1e9" },
            { "DE", "\ua113\ua1e9" },
            { "FR", "\ua0d4\ua1e9" },
            { "GB", "\ua471\ua1e9" },
            { "IN", "\ua474\ua117" },
            { "IT", "\ua474\ua10a\ua1ba" },
            { "JP", "\ua3dd\ua02a" },
            { "RU", "\ua289\ua1c6\ua326" },
            { "US", "\ua0b0\ua1e9" },
            { "ZZ", "\ua0c5\ua137\ua149\ua00b\ua41a\ua320" },
            { "de", "\ua113\ua1e9\ua259" },
            { "en", "\ua471\ua1e9\ua259" },
            { "es", "\ua46d\ua020\ua478\ua259" },
            { "fr", "\ua0d4\ua1e9\ua259" },
            { "ii", "\ua188\ua320\ua259" },
            { "it", "\ua474\ua10a\ua1ba\ua259" },
            { "ja", "\ua3dd\ua02a\ua259" },
            { "pt", "\ua04d\ua128\ua478\ua259" },
            { "ru", "\ua289\ua1e9\ua259" },
            { "zh", "\ua34f\ua1e9\ua259" },
            { "und", "\ua149\ua00b\ua320\ua147\ua0b7" },
            { "Arab", "\ua00a\ua1c1\ua028\ua071\ua0b7" },
            { "Cyrl", "\ua00a\ua1a8\ua326\ua1c1\ua0da\ua071\ua0b7" },
            { "Hans", "\ua21d\ua42f\ua24c\ua232\ua071\ua0b7" },
            { "Hant", "\ua00e\ua2cf\ua24c\ua232\ua071\ua0b7" },
            { "Latn", "\ua1c1\ua100\ua071\ua0b7" },
            { "Yiii", "\ua188\ua320\ua071\ua0b7" },
            { "Zxxx", "\ua071\ua00b\ua246\ua320" },
            { "Zzzz", "\ua149\ua00b\ua41a\ua320\ua071\ua0b7" },
            { "type.ca.gregorian", "\ua109\ua27b\ua0c5\ua44d" },
        };
        return data;
    }
}

==> openjdk-src-24.0.2.u12-1-aarch64.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/LocaleNames_ii.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class LocaleNames_ii extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "001", "\ua2e7\ua0c5" },
            { "002", "\ua0cf\ua34f" },
            { "003", "\ua019\ua0b0\ua34f" },
            { "005", "\ua186\ua0b0\ua34f" },
            { "009", "\ua10a\ua478\ua34f" },
            { "019", "\ua0b0\ua34f" },
            { "142", "\ua478\ua34f" },
            { "150", "\ua269\ua34f" },
            { "BE", "\ua018\ua1b9\ua3c3" },
            { "BR", "\ua020\ua46d" },
            { "CN", "\ua34f\ua1e9" },
            { "DE", "\ua113\ua1e9" },
            { "FR", "\ua0d4\ua1e9" },
            { "GB", "\ua471\ua1e9" },
            { "IN", "\ua474\ua117" },
            { "IT", "\ua474\ua10a\ua1ba" },
            { "JP", "\ua3dd\ua02a" },
            { "MX", "\ua0c0\ua46d\ua1ec" },
            { "RU", "\ua289\ua1c6\ua326" },
            { "US", "\ua0b0\ua1e9" },
            { "ZZ", "\ua0c5\ua137\ua149\ua00b\ua41a\ua320" },
            { "ar", "\ua00a\ua1c1\ua028\ua259" },
            { "de", "\ua113\ua1e9\ua259" },
            { "en", "\ua471\ua1e9\ua259" },
            { "es", "\ua46d\ua020\ua478\ua259" },
            { "fr", "\ua0d4\ua1e9\ua259" },
            { "hi", "\ua474\ua103\ua259" },
            { "ii", "\ua188\ua320\ua259" },
            { "it", "\ua474\ua10a\ua1ba\ua259" },
            { "ja", "\ua3dd\ua02a\ua259" },
            { "nl", "\ua27f\ua1c2\ua259" },
            { "pt", "\ua04d\ua128\ua478\ua259" },
            { "ro", "\ua1c6\ua0b7\ua180\ua478\ua259" },
            { "ru", "\ua289\ua1e9\ua259" },
            { "sw", "\ua316\ua45f\ua1ba\ua259" },
            { "zh", "\ua34f\ua1e9\ua259" },
            { "nds", "\ua0c5\ua137\ua001\ua0a5\ua113\ua259" },
            { "und", "\ua149\ua00b\ua320\ua147\ua0b7" },
            { "Arab", "\ua00a\ua1c1\ua028\ua071\ua0b7" },
            { "Cyrl", "\ua00a\ua1a8\ua326\ua1c1\ua0da\ua071\ua0b7" },
            { "Hans", "\ua21d\ua42e\ua071\ua0b7" },
            { "Hant", "\ua00e\ua2cf\ua071\ua0b7" },
            { "Latn", "\ua1c1\ua102\ua071\ua0b7" },
            { "Yiii", "\ua188\ua320\ua071\ua0b7" },
            { "Zxxx", "\ua071\ua00b\ua246\ua320" },
            { "Zzzz", "\ua149\ua00b\ua41a\ua320\ua071\ua0b7" },
            { "ar_001", "\ua00a\ua1c1\ua028\ua259\uff08\ua2e7\ua0c5\uff09" },
            { "key.ca", "\ua20e\ua317" },
            { "type.nu.latn", "\ua00a\ua1bf\ua019\ua0f7\ua068\ua071\ua0b7" },
            { "type.ca.gregorian", "\ua109\ua27b\ua0c5\ua44d" },
            { "ListCompositionPattern", "{0}\uff0c{1}" },
        };
        return data;
    }
}
